.. _versioning:

Versioning
==========

Version numbers comply with the `Sementic Versioning Specification (SemVer)`_.

In summary, version numbers are written in the form ``MAJOR.MINOR.PATCH``
where:

    * incompatible API changes increment the MAJOR version.
    * functionalities added in a backwards-compatible manner increment the
      MINOR version.
    * backwards-compatible bug fixes increment the PATCH version.


Major version zero (0.y.z) is considered a special case denoting an initial
development phase. Anything may change at any time without the MAJOR version
being incremented.

.. _Sementic Versioning Specification (SemVer): http://semver.org
